@@ -3,7 +3,7 @@
 /*
     Rubber Band Library
     An audio time-stretching and pitch-shifting library.
-    Copyright 2007-2022 Particular Programs Ltd.
+    Copyright 2007-2024 Particular Programs Ltd.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -24,16 +24,20 @@
 #ifndef RUBBERBAND_STRETCHER_H
 #define RUBBERBAND_STRETCHER_H
     
-#define RUBBERBAND_VERSION "3.2.1"
-#define RUBBERBAND_API_MAJOR_VERSION 2
-#define RUBBERBAND_API_MINOR_VERSION 7
+#define RUBBERBAND_VERSION "4.0.0"
+#define RUBBERBAND_API_MAJOR_VERSION 3
+#define RUBBERBAND_API_MINOR_VERSION 0
 
 #undef RUBBERBAND_DLLEXPORT
 #ifdef _MSC_VER
+#ifndef RUBBERBAND_STATIC
 #define RUBBERBAND_DLLEXPORT __declspec(dllexport)
 #else
 #define RUBBERBAND_DLLEXPORT
 #endif
+#else
+#define RUBBERBAND_DLLEXPORT
+#endif
 
 #include <vector>
 #include <map>
@@ -49,13 +53,16 @@ namespace RubberBand
  *
  * ### Summary
  * 
- * The Rubber Band Library API is contained in the single class
- * RubberBand::RubberBandStretcher.
+ * The primary Rubber Band Library API is contained in the class
+ * RubberBand::RubberBandStretcher. This class can perform both pitch
+ * shifting and time stretching and supports every feature of the
+ * library. A simpler, more limited API that supports only
+ * pitch-shifting can be found in RubberBand::RubberBandLiveShifter.
  *
- * The Rubber Band stretcher supports two processing modes, offline
- * and real-time, and two processing "engines", known as the R2 or
- * Faster engine and the R3 or Finer engine. The choices of processing
- * mode and engine are fixed on construction: see
+ * RubberBandStretcher supports two processing modes, offline and
+ * real-time, and two processing "engines", known as the R2 or Faster
+ * engine and the R3 or Finer engine. The choices of processing mode
+ * and engine are fixed on construction: see the constructor
  * RubberBandStretcher::RubberBandStretcher. The two engines work
  * identically in API terms, and both of them support both offline and
  * real-time modes as described below.
@@ -803,6 +810,13 @@ public:
      * study() (to which you may pass any number of samples at a time,
      * and from which there is no output).
      *
+     * Despite the existence of this call and its use of a size_t
+     * argument, there is an internal limit to the maximum process
+     * buffer size that can be requested. Call getProcessSizeLimit()
+     * to query that limit. The Rubber Band API is essentially
+     * block-based and is not designed to process an entire signal
+     * within a single process cycle.
+     *
      * Note that the value of "samples" refers to the number of audio
      * sample frames, which may be multi-channel, not the number of
      * individual samples. (For example, one second of stereo audio
@@ -811,6 +825,18 @@ public:
      */
     void setMaxProcessSize(size_t samples);
 
+    /**
+     * Obtain the overall maximum supported process buffer size in
+     * sample frames, which is also the maximum acceptable value to
+     * pass to setMaxProcessSize(). This value is fixed across
+     * instances and configurations. As of Rubber Band v3.3 it is
+     * always 524288 (or 2^19), but in principle it may change in
+     * future releases.
+     *
+     * This function was added in Rubber Band Library v3.3.
+     */
+    size_t getProcessSizeLimit() const;
+    
     /**
      * Ask the stretcher how many audio sample frames should be
      * provided as input in order to ensure that some more output
@@ -820,10 +846,10 @@ public:
      * block size and you are able to provide any block size as input
      * for each cycle, then your normal mode of operation would be to
      * loop querying this function; providing that number of samples
-     * to process(); and reading the output using available() and
-     * retrieve().  See setMaxProcessSize() for a more suitable
-     * operating mode for applications that do have external block
-     * size constraints.
+     * to process(); and reading the output (repeatedly if necessary)
+     * using available() and retrieve().  See setMaxProcessSize() for
+     * a more suitable operating mode for applications that do have
+     * external block size constraints.
      *
      * Note that this value is only relevant to process(), not to
      * study() (to which you may pass any number of samples at a time,
